        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <strong>control</strong><br>0,1,3,5,6,9,12,16,18,20,21,22,23,27,28,30,31,33,34,35,38,39,40,41,42,44,46,47,48,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <br>2,4,7,8,10,11,13,14,15,17,19,24,25,26,29,32,36,37,43,45';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <strong>control</strong><br>0,1,3,5,6,9,12,16,18,20,21,22,23,27,28,30,31,33,34,35,38,39,40,41,42,44,46,47,48,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <br>2,4,7,8,10,11,13,14,15,17,19,24,25,26,29,32,36,37,43,45';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <strong>control</strong><br>0,1,3,5,6,9,12,16,18,20,21,22,23,27,28,30,31,33,34,35,38,39,40,41,42,44,46,47,48,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <br>2,4,7,8,10,11,13,14,15,17,19,24,25,26,29,32,36,37,43,45';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <strong>control</strong><br>0,1,3,5,6,9,12,16,18,20,21,22,23,27,28,30,31,33,34,35,38,39,40,41,42,44,46,47,48,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <br>2,4,7,8,10,11,13,14,15,17,19,24,25,26,29,32,36,37,43,45';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <strong>control</strong><br>0,1,3,5,6,9,12,16,18,20,21,22,23,27,28,30,31,33,34,35,38,39,40,41,42,44,46,47,48,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <br>2,4,7,8,10,11,13,14,15,17,19,24,25,26,29,32,36,37,43,45';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <strong>control</strong><br>0,1,3,5,6,9,12,16,18,20,21,22,23,27,28,30,31,33,34,35,38,39,40,41,42,44,46,47,48,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260515 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <br>2,4,7,8,10,11,13,14,15,17,19,24,25,26,29,32,36,37,43,45';}
}
